summaryrefslogtreecommitdiffstats
path: root/kimgio/exr.h
diff options
context:
space:
mode:
Diffstat (limited to 'kimgio/exr.h')
-rw-r--r--kimgio/exr.h6
1 files changed, 3 insertions, 3 deletions
diff --git a/kimgio/exr.h b/kimgio/exr.h
index 9a039c6c6..04bd6d956 100644
--- a/kimgio/exr.h
+++ b/kimgio/exr.h
@@ -1,5 +1,5 @@
/**
* QImageIO Routines to read (and perhaps in the future, write) images
* in the high definition EXR format.
*
* Copyright (c) 2003, Brad Hards <bradh@frogmouth.net>
@@ -14,8 +14,8 @@
class QImageIO;
extern "C" {
- void kimgio_exr_read (QImageIO *io);
- void kimgio_exr_write (QImageIO *io);
+ void kimgio_exr_read (TQImageIO *io);
+ void kimgio_exr_write (TQImageIO *io);
}
#endif
@@ -1,5 +1,5 @@
/**
-* QImageIO Routines to read (and perhaps in the future, write) images
+* TQImageIO Routines to read (and perhaps in the future, write) images
* in the high definition EXR format.
*